==> ejc-middlemeasurement-impl-3.0.0-20220621.090612-110-sources.jar: com/ejianc/business/middlemeasurement/bean/SubcontractvisadetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包经济签证月清确认子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_subcontractvisadetail")
public class SubcontractvisadetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="subcontracting_mode")
    private java.lang.String subcontractingMode; // 分包方式
    @TableField(value="visa_code")
    private java.lang.String visaCode; // 签证编号
    @TableField(value="visa_content")
    private java.lang.String visaContent; // 签证主要内容
    @TableField(value="submission_date")
    private java.util.Date submissionDate; // 分包报送日期
    @TableField(value="submitted_value")
    private java.math.BigDecimal submittedValue; // 报送值(元)
    @TableField(value="visaagent_id")
    private java.lang.Long visaagentId; // 签证经办人
    @TableField(value="visaagent_name")
    private java.lang.String visaagentName; // 签证经办人姓名
    @TableField(value="visa_submission_date")
    private java.util.Date visaSubmissionDate; // 签证提交日期
    @TableField(value="approval_date")
    private java.util.Date approvalDate; // 项目部审批日期
    @TableField(value="ex_visa_amount")
    private java.math.BigDecimal exVisaAmount; // 签证金额(除税)(元)
    @TableField(value="in_visa_amount")
    private java.math.BigDecimal inVisaAmount; // 签证金额(含税)(元)
    @TableField(value="ex_visa_oddjob")
    private java.math.BigDecimal exVisaOddjob; // 其中签证零工(除税)(元)
    @TableField(value="in_visa_oddjob")
    private java.math.BigDecimal inVisaOddjob; // 其中签证零工(含税)(元)
    @TableField(value="total_detail")
    private java.math.BigDecimal totalDetail; // 合计(元)
    @TableField(value="unit_situation")
    private java.lang.String unitSituation; // 分包签证转扣单位情况
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 分包方式
     */
    public java.lang.String getSubcontractingMode() {
        return subcontractingMode;
    }

    /**
     * 分包方式
     */
    public void setSubcontractingMode(java.lang.String subcontractingMode) {
        this.subcontractingMode = subcontractingMode;
    }
    /**
     * 签证编号
     */
    public java.lang.String getVisaCode() {
        return visaCode;
    }

    /**
     * 签证编号
     */
    public void setVisaCode(java.lang.String visaCode) {
        this.visaCode = visaCode;
    }
    /**
     * 签证主要内容
     */
    public java.lang.String getVisaContent() {
        return visaContent;
    }

    /**
     * 签证主要内容
     */
    public void setVisaContent(java.lang.String visaContent) {
        this.visaContent = visaContent;
    }
    /**
     * 分包报送日期
     */
    public java.util.Date getSubmissionDate() {
        return submissionDate;
    }

    /**
     * 分包报送日期
     */
    public void setSubmissionDate(java.util.Date submissionDate) {
        this.submissionDate = submissionDate;
    }
    /**
     * 报送值(元)
     */
    public java.math.BigDecimal getSubmittedValue() {
        return submittedValue;
    }

    /**
     * 报送值(元)
     */
    public void setSubmittedValue(java.math.BigDecimal submittedValue) {
        this.submittedValue = submittedValue;
    }
    /**
     * 签证经办人
     */
    public java.lang.Long getVisaagentId() {
        return visaagentId;
    }

    /**
     * 签证经办人
     */
    public void setVisaagentId(java.lang.Long visaagentId) {
        this.visaagentId = visaagentId;
    }
    /**
     * 签证经办人姓名
     */
    public java.lang.String getVisaagentName() {
        return visaagentName;
    }

    /**
     * 签证经办人姓名
     */
    public void setVisaagentName(java.lang.String visaagentName) {
        this.visaagentName = visaagentName;
    }
    /**
     * 签证提交日期
     */
    public java.util.Date getVisaSubmissionDate() {
        return visaSubmissionDate;
    }

    /**
     * 签证提交日期
     */
    public void setVisaSubmissionDate(java.util.Date visaSubmissionDate) {
        this.visaSubmissionDate = visaSubmissionDate;
    }
    /**
     * 项目部审批日期
     */
    public java.util.Date getApprovalDate() {
        return approvalDate;
    }

    /**
     * 项目部审批日期
     */
    public void setApprovalDate(java.util.Date approvalDate) {
        this.approvalDate = approvalDate;
    }
    /**
     * 签证金额(除税)(元)
     */
    public java.math.BigDecimal getExVisaAmount() {
        return exVisaAmount;
    }

    /**
     * 签证金额(除税)(元)
     */
    public void setExVisaAmount(java.math.BigDecimal exVisaAmount) {
        this.exVisaAmount = exVisaAmount;
    }
    /**
     * 签证金额(含税)(元)
     */
    public java.math.BigDecimal getInVisaAmount() {
        return inVisaAmount;
    }

    /**
     * 签证金额(含税)(元)
     */
    public void setInVisaAmount(java.math.BigDecimal inVisaAmount) {
        this.inVisaAmount = inVisaAmount;
    }
    /**
     * 其中签证零工(除税)(元)
     */
    public java.math.BigDecimal getExVisaOddjob() {
        return exVisaOddjob;
    }

    /**
     * 其中签证零工(除税)(元)
     */
    public void setExVisaOddjob(java.math.BigDecimal exVisaOddjob) {
        this.exVisaOddjob = exVisaOddjob;
    }
    /**
     * 其中签证零工(含税)(元)
     */
    public java.math.BigDecimal getInVisaOddjob() {
        return inVisaOddjob;
    }

    /**
     * 其中签证零工(含税)(元)
     */
    public void setInVisaOddjob(java.math.BigDecimal inVisaOddjob) {
        this.inVisaOddjob = inVisaOddjob;
    }
    /**
     * 合计(元)
     */
    public java.math.BigDecimal getTotalDetail() {
        return totalDetail;
    }

    /**
     * 合计(元)
     */
    public void setTotalDetail(java.math.BigDecimal totalDetail) {
        this.totalDetail = totalDetail;
    }
    /**
     * 分包签证转扣单位情况
     */
    public java.lang.String getUnitSituation() {
        return unitSituation;
    }

    /**
     * 分包签证转扣单位情况
     */
    public void setUnitSituation(java.lang.String unitSituation) {
        this.unitSituation = unitSituation;
    }
    
}

==> ejc-middlemeasurement-impl-3.0.0-20221219.062630-293-sources.jar: com/ejianc/business/middlemeasurement/bean/SubcontractvisadetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 分包经济签证月清确认子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_subcontractvisadetail")
public class SubcontractvisadetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="subcontracting_mode")
    private java.lang.String subcontractingMode; // 分包方式
    @TableField(value="visa_code")
    private java.lang.String visaCode; // 签证编号
    @TableField(value="visa_content")
    private java.lang.String visaContent; // 签证主要内容
    @TableField(value="submission_date")
    private java.util.Date submissionDate; // 分包报送日期
    @TableField(value="submitted_value")
    private java.math.BigDecimal submittedValue; // 报送值(元)
    @TableField(value="visaagent_id")
    private java.lang.Long visaagentId; // 签证经办人
    @TableField(value="visaagent_name")
    private java.lang.String visaagentName; // 签证经办人姓名
    @TableField(value="visa_submission_date")
    private java.util.Date visaSubmissionDate; // 签证提交日期
    @TableField(value="approval_date")
    private java.util.Date approvalDate; // 项目部审批日期
    @TableField(value="ex_visa_amount")
    private java.math.BigDecimal exVisaAmount; // 签证金额(除税)(元)
    @TableField(value="in_visa_amount")
    private java.math.BigDecimal inVisaAmount; // 签证金额(含税)(元)
    @TableField(value="ex_visa_oddjob")
    private java.math.BigDecimal exVisaOddjob; // 其中签证零工(除税)(元)
    @TableField(value="in_visa_oddjob")
    private java.math.BigDecimal inVisaOddjob; // 其中签证零工(含税)(元)
    @TableField(value="total_detail")
    private java.math.BigDecimal totalDetail; // 合计(元)
    @TableField(value="unit_situation")
    private java.lang.String unitSituation; // 分包签证转扣单位情况

    @TableField(value="tax_visa_amount")
    private java.math.BigDecimal taxVisaAmount; // 签证金额(税金)(元)
    @TableField(value="tax_casual_labour")
    private java.math.BigDecimal taxCasualLabour; // 期中签证零工(税金)(元)

    public BigDecimal getTaxVisaAmount() {
        return taxVisaAmount;
    }

    public void setTaxVisaAmount(BigDecimal taxVisaAmount) {
        this.taxVisaAmount = taxVisaAmount;
    }

    public BigDecimal getTaxCasualLabour() {
        return taxCasualLabour;
    }

    public void setTaxCasualLabour(BigDecimal taxCasualLabour) {
        this.taxCasualLabour = taxCasualLabour;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 分包方式
     */
    public java.lang.String getSubcontractingMode() {
        return subcontractingMode;
    }

    /**
     * 分包方式
     */
    public void setSubcontractingMode(java.lang.String subcontractingMode) {
        this.subcontractingMode = subcontractingMode;
    }
    /**
     * 签证编号
     */
    public java.lang.String getVisaCode() {
        return visaCode;
    }

    /**
     * 签证编号
     */
    public void setVisaCode(java.lang.String visaCode) {
        this.visaCode = visaCode;
    }
    /**
     * 签证主要内容
     */
    public java.lang.String getVisaContent() {
        return visaContent;
    }

    /**
     * 签证主要内容
     */
    public void setVisaContent(java.lang.String visaContent) {
        this.visaContent = visaContent;
    }
    /**
     * 分包报送日期
     */
    public java.util.Date getSubmissionDate() {
        return submissionDate;
    }

    /**
     * 分包报送日期
     */
    public void setSubmissionDate(java.util.Date submissionDate) {
        this.submissionDate = submissionDate;
    }
    /**
     * 报送值(元)
     */
    public java.math.BigDecimal getSubmittedValue() {
        return submittedValue;
    }

    /**
     * 报送值(元)
     */
    public void setSubmittedValue(java.math.BigDecimal submittedValue) {
        this.submittedValue = submittedValue;
    }
    /**
     * 签证经办人
     */
    public java.lang.Long getVisaagentId() {
        return visaagentId;
    }

    /**
     * 签证经办人
     */
    public void setVisaagentId(java.lang.Long visaagentId) {
        this.visaagentId = visaagentId;
    }
    /**
     * 签证经办人姓名
     */
    public java.lang.String getVisaagentName() {
        return visaagentName;
    }

    /**
     * 签证经办人姓名
     */
    public void setVisaagentName(java.lang.String visaagentName) {
        this.visaagentName = visaagentName;
    }
    /**
     * 签证提交日期
     */
    public java.util.Date getVisaSubmissionDate() {
        return visaSubmissionDate;
    }

    /**
     * 签证提交日期
     */
    public void setVisaSubmissionDate(java.util.Date visaSubmissionDate) {
        this.visaSubmissionDate = visaSubmissionDate;
    }
    /**
     * 项目部审批日期
     */
    public java.util.Date getApprovalDate() {
        return approvalDate;
    }

    /**
     * 项目部审批日期
     */
    public void setApprovalDate(java.util.Date approvalDate) {
        this.approvalDate = approvalDate;
    }
    /**
     * 签证金额(除税)(元)
     */
    public java.math.BigDecimal getExVisaAmount() {
        return exVisaAmount;
    }

    /**
     * 签证金额(除税)(元)
     */
    public void setExVisaAmount(java.math.BigDecimal exVisaAmount) {
        this.exVisaAmount = exVisaAmount;
    }
    /**
     * 签证金额(含税)(元)
     */
    public java.math.BigDecimal getInVisaAmount() {
        return inVisaAmount;
    }

    /**
     * 签证金额(含税)(元)
     */
    public void setInVisaAmount(java.math.BigDecimal inVisaAmount) {
        this.inVisaAmount = inVisaAmount;
    }
    /**
     * 其中签证零工(除税)(元)
     */
    public java.math.BigDecimal getExVisaOddjob() {
        return exVisaOddjob;
    }

    /**
     * 其中签证零工(除税)(元)
     */
    public void setExVisaOddjob(java.math.BigDecimal exVisaOddjob) {
        this.exVisaOddjob = exVisaOddjob;
    }
    /**
     * 其中签证零工(含税)(元)
     */
    public java.math.BigDecimal getInVisaOddjob() {
        return inVisaOddjob;
    }

    /**
     * 其中签证零工(含税)(元)
     */
    public void setInVisaOddjob(java.math.BigDecimal inVisaOddjob) {
        this.inVisaOddjob = inVisaOddjob;
    }
    /**
     * 合计(元)
     */
    public java.math.BigDecimal getTotalDetail() {
        return totalDetail;
    }

    /**
     * 合计(元)
     */
    public void setTotalDetail(java.math.BigDecimal totalDetail) {
        this.totalDetail = totalDetail;
    }
    /**
     * 分包签证转扣单位情况
     */
    public java.lang.String getUnitSituation() {
        return unitSituation;
    }

    /**
     * 分包签证转扣单位情况
     */
    public void setUnitSituation(java.lang.String unitSituation) {
        this.unitSituation = unitSituation;
    }
    
}
